abacusai.feature_group_lineage — AbacusAI documentation

# abacusai.feature_group_lineage

## Classes

`AbstractApiClass` |
`FeatureGroupLineage` | Directed acyclic graph of feature group lineage for all feature groups in a project

## Module Contents

class abacusai.feature_group_lineage.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.feature_group_lineage.FeatureGroupLineage(client, nodes=None, connections=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Directed acyclic graph of feature group lineage for all feature groups in a project

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - nodes (list<dict>) – A list of nodes in the graph containing feature groups and datasets

    - connections (list<dict>) – A list of connections in the graph between nodes

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict